@@ -31,8 +31,8 @@ print(raw_sigs.shape, raw_sigs.dtype)
 print(float_sigs.shape, float_sigs.dtype)
 print(sampling_rate, t_start, units)
 
-# Count unit and spike per units
-nb_unit = reader.unit_channels_count()
+# Count units and spikes per unit
+nb_unit = reader.spike_channels_count()
 print('nb_unit', nb_unit)
 for unit_index in range(nb_unit):
     nb_spike = reader.spike_count(block_index=0, seg_index=0, unit_index=unit_index)
