@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from neo.io.basefromrawio import BaseFromRaw
 from neo.rawio.spike2rawio import Spike2RawIO
 
@@ -7,6 +5,6 @@ from neo.rawio.spike2rawio import Spike2RawIO
 class Spike2IO(Spike2RawIO, BaseFromRaw):
     _prefered_signal_group_mode = 'group-by-same-units'
 
-    def __init__(self, filename):
-        Spike2RawIO.__init__(self, filename=filename)
+    def __init__(self, filename, **kargs):
+        Spike2RawIO.__init__(self, filename=filename, **kargs)
         BaseFromRaw.__init__(self, filename)
