@@ -6,18 +6,18 @@ This is to be used when coding a new RawIO.
 Rules for creating a new class:
   1. Step 1: Create the main class
     * Create a file in **neo/rawio/** that endith with "rawio.py"
-    * Create the class that inherits BaseRawIO
+    * Create the class that inherits from BaseRawIO
     * copy/paste all methods that need to be implemented.
-      See the end a neo.rawio.baserawio.BaseRawIO
-    * code hard! The main difficulty **is _parse_header()**.
+    * code hard! The main difficulty is `_parse_header()`.
       In short you have a create a mandatory dict than
       contains channel informations::
 
             self.header = {}
             self.header['nb_block'] = 2
             self.header['nb_segment'] = [2, 3]
-            self.header['signal_channels'] = sig_channels
-            self.header['unit_channels'] = unit_channels
+            self.header['signal_streams'] = signal_streams
+            self.header['signal_channels'] = signal_channels
+            self.header['spike_channels'] = spike_channels
             self.header['event_channels'] = event_channels
 
   2. Step 2: RawIO test:
@@ -25,8 +25,8 @@ Rules for creating a new class:
     * copy paste neo/rawio/tests/test_examplerawio.py and do the same
 
   3. Step 3 : Create the neo.io class with the wrapper
-    * Create a file in neo/io/ that endith with "io.py"
-    * Create a that inherits both your RawIO class and BaseFromRaw class
+    * Create a file in neo/io/ that ends with "io.py"
+    * Create a class that inherits both your RawIO class and BaseFromRaw class
     * copy/paste from neo/io/exampleio.py
 
   4.Step 4 : IO test
@@ -37,8 +37,8 @@ Rules for creating a new class:
 
 """
 
-from .baserawio import (BaseRawIO, _signal_channel_dtype, _unit_channel_dtype,
-                        _event_channel_dtype)
+from .baserawio import (BaseRawIO, _signal_channel_dtype, _signal_stream_dtype,
+                _spike_channel_dtype, _event_channel_dtype)
 
 import numpy as np
 
@@ -47,7 +47,7 @@ class ExampleRawIO(BaseRawIO):
     """
     Class for "reading" fake data from an imaginary file.
 
-    For the user, it give acces to raw data (signals, event, spikes) as they
+    For the user, it gives access to raw data (signals, event, spikes) as they
     are in the (fake) file int16 and int64.
 
     For a developer, it is just an example showing guidelines for someone who wants
@@ -58,11 +58,11 @@ class ExampleRawIO(BaseRawIO):
       * Follow the :ref:`io_guiline`
 
     This fake IO:
-        * have 2 blocks
+        * has 2 blocks
         * blocks have 2 and 3 segments
-        * have 16 signal_channel sample_rate = 10000
-        * have 3 unit_channel
-        * have 2 event channel: one have *type=event*, the other have
+        * has  2 signals streams  of 8 channel each (sample_rate = 10000) so 16 channels in total
+        * has 3 spike_channels
+        * has 2 event channels: one has *type=event*, the other has
           *type=epoch*
 
 
@@ -75,7 +75,8 @@ class ExampleRawIO(BaseRawIO):
                             i_start=0, i_stop=1024,  channel_names=channel_names)
         >>> float_chunk = reader.rescale_signal_raw_to_float(raw_chunk, dtype='float64',
                             channel_indexes=[0, 3, 6])
-        >>> spike_timestamp = reader.spike_timestamps(unit_index=0, t_start=None, t_stop=None)
+        >>> spike_timestamp = reader.spike_timestamps(spike_channel_index=0,
+                            t_start=None, t_stop=None)
         >>> spike_times = reader.rescale_spike_timestamp(spike_timestamp, 'float64')
         >>> ev_timestamps, _, ev_labels = reader.event_timestamps(event_channel_index=0)
 
@@ -96,23 +97,31 @@ class ExampleRawIO(BaseRawIO):
         return self.filename
 
     def _parse_header(self):
-        # This is the central of a RawIO
-        # we need to collect in the original format all
-        # informations needed for further fast acces
+        # This is the central part of a RawIO
+        # we need to collect from the original format all
+        # information required for fast access
         # at any place in the file
-        # In short _parse_header can be slow but
-        # _get_analogsignal_chunk need to be as fast as possible
+        # In short `_parse_header()` can be slow but
+        # `_get_analogsignal_chunk()` need to be as fast as possible
 
-        # create signals channels information
+        # create fake signals stream information
+        signal_streams = []
+        for c in range(2):
+            name = f'stream {c}'
+            stream_id = c
+            signal_streams.append((name, stream_id))
+        signal_streams = np.array(signal_streams, dtype=_signal_stream_dtype)
+
+        # create fake signals channels information
         # This is mandatory!!!!
         # gain/offset/units are really important because
         # the scaling to real value will be done with that
-        # at the end real_signal = (raw_signal* gain + offset) * pq.Quantity(units)
-        sig_channels = []
+        # The real signal will be evaluated as `(raw_signal * gain + offset) * pq.Quantity(units)`
+        signal_channels = []
         for c in range(16):
             ch_name = 'ch{}'.format(c)
             # our channel id is c+1 just for fun
-            # Note that chan_id should be realated to
+            # Note that chan_id should be related to
             # original channel id in the file format
             # so that the end user should not be lost when reading datasets
             chan_id = c + 1
@@ -121,20 +130,27 @@ class ExampleRawIO(BaseRawIO):
             units = 'uV'
             gain = 1000. / 2 ** 16
             offset = 0.
-            # group_id isonly for special cases when channel have diferents
-            # sampling rate for instance. See TdtIO for that.
-            # Here this is the general case :all channel have the same characteritics
-            group_id = 0
-            sig_channels.append((ch_name, chan_id, sr, dtype, units, gain, offset, group_id))
-        sig_channels = np.array(sig_channels, dtype=_signal_channel_dtype)
+            # stream_id indicates how to group channels
+            # channels inside a "stream" share same characteristics
+            #  (sampling rate/dtype/t_start/units/...)
+            stream_id = str(c // 8)
+            signal_channels.append((ch_name, chan_id, sr, dtype, units, gain, offset, stream_id))
+        signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
 
-        # creating units channels
+        # A stream can contain signals with different physical units.
+        # Here, the two last channels will have different units (pA)
+        # Since AnalogSignals must have consistent units across channels,
+        # this stream will be split in 2 parts on the neo.io level and finally 3 AnalogSignals
+        # will be generated per Segment.
+        signal_channels[-2:]['units'] = 'pA'
+
+        # create fake units channels
         # This is mandatory!!!!
         # Note that if there is no waveform at all in the file
         # then wf_units/wf_gain/wf_offset/wf_left_sweep/wf_sampling_rate
         # can be set to any value because _spike_raw_waveforms
         # will return None
-        unit_channels = []
+        spike_channels = []
         for c in range(3):
             unit_name = 'unit{}'.format(c)
             unit_id = '#{}'.format(c)
@@ -143,9 +159,9 @@ class ExampleRawIO(BaseRawIO):
             wf_offset = 0.
             wf_left_sweep = 20
             wf_sampling_rate = 10000.
-            unit_channels.append((unit_name, unit_id, wf_units, wf_gain,
+            spike_channels.append((unit_name, unit_id, wf_units, wf_gain,
                                   wf_offset, wf_left_sweep, wf_sampling_rate))
-        unit_channels = np.array(unit_channels, dtype=_unit_channel_dtype)
+        spike_channels = np.array(spike_channels, dtype=_spike_channel_dtype)
 
         # creating event/epoch channel
         # This is mandatory!!!!
@@ -160,16 +176,26 @@ class ExampleRawIO(BaseRawIO):
         self.header = {}
         self.header['nb_block'] = 2
         self.header['nb_segment'] = [2, 3]
-        self.header['signal_channels'] = sig_channels
-        self.header['unit_channels'] = unit_channels
+        self.header['signal_streams'] = signal_streams
+        self.header['signal_channels'] = signal_channels
+        self.header['spike_channels'] = spike_channels
         self.header['event_channels'] = event_channels
 
-        # insert some annotation at some place
-        # at neo.io level IO are free to add some annoations
+        # insert some annotations/array_annotations at some place
+        # at neo.io level. IOs can add annotations
         # to any object. To keep this functionality with the wrapper
-        # BaseFromRaw you can add annoations in a nested dict.
+        # BaseFromRaw you can add annotations in a nested dict.
+
+        # `_generate_minimal_annotations()` must be called to generate the nested
+        # dict of annotations/array_annotations
         self._generate_minimal_annotations()
-        # If you are a lazy dev you can stop here.
+        # this pprint lines really help for understand the nested (and complicated sometimes) dict
+        # from pprint import pprint
+        # pprint(self.raw_annotations)
+
+        # Until here all mandatory operations for setting up a rawio are implemented.
+        # The following lines provide additional, recommended annotations for the
+        # final neo objects.
         for block_index in range(2):
             bl_ann = self.raw_annotations['blocks'][block_index]
             bl_ann['name'] = 'Block #{}'.format(block_index)
@@ -180,16 +206,27 @@ class ExampleRawIO(BaseRawIO):
                     seg_index, block_index)
                 seg_ann['seg_extra_info'] = 'This is the seg {} of block {}'.format(
                     seg_index, block_index)
-                for c in range(16):
-                    anasig_an = seg_ann['signals'][c]
-                    anasig_an['info'] = 'This is a good signals'
+                for c in range(2):
+                    sig_an = seg_ann['signals'][c]['nickname'] = \
+                        f'This stream {c} is from a subdevice'
+                    # add some array annotations (8 channels)
+                    sig_an = seg_ann['signals'][c]['__array_annotations__']['impedance'] = \
+                        np.random.rand(8) * 10000
                 for c in range(3):
-                    spiketrain_an = seg_ann['units'][c]
+                    spiketrain_an = seg_ann['spikes'][c]
                     spiketrain_an['quality'] = 'Good!!'
+                    # add some array annotations
+                    num_spikes = self.spike_count(block_index, seg_index, c)
+                    spiketrain_an['__array_annotations__']['amplitudes'] = \
+                        np.random.randn(num_spikes)
+
                 for c in range(2):
                     event_an = seg_ann['events'][c]
                     if c == 0:
                         event_an['nickname'] = 'Miss Event 0'
+                        # add some array annotations
+                        num_ev = self.event_count(block_index, seg_index, c)
+                        event_an['__array_annotations__']['button'] = ['A'] * num_ev
                     elif c == 1:
                         event_an['nickname'] = 'MrEpoch 1'
 
@@ -205,16 +242,18 @@ class ExampleRawIO(BaseRawIO):
         all_stops = [[10., 25.], [10., 30., 70.]]
         return all_stops[block_index][seg_index]
 
-    def _get_signal_size(self, block_index, seg_index, channel_indexes=None):
-        # we are lucky: signals in all segment have the same shape!! (10.0 seconds)
-        # it is not always the case
+    def _get_signal_size(self, block_index, seg_index, stream_index):
+        # We generate fake data in which the two stream signals have the same shape
+        # across all segments (10.0 seconds)
+        # This is not the case for real data, instead you should return the signal
+        # size depending on the block_index and segment_index
         # this must return an int = the number of sample
 
         # Note that channel_indexes can be ignored for most cases
         # except for several sampling rate.
         return 100000
 
-    def _get_signal_t_start(self, block_index, seg_index, channel_indexes):
+    def _get_signal_t_start(self, block_index, seg_index, stream_index):
         # This give the t_start of signals.
         # Very often this equal to _segment_t_start but not
         # always.
@@ -227,17 +266,19 @@ class ExampleRawIO(BaseRawIO):
         # this is not always the case
         return self._segment_t_start(block_index, seg_index)
 
-    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop, channel_indexes):
-        # this must return a signal chunk limited with
-        # i_start/i_stop (can be None)
-        # channel_indexes can be None (=all channel) or a list or numpy.array
+    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop,
+                                stream_index, channel_indexes):
+        # this must return a signal chunk in a signal stream
+        # limited with i_start/i_stop (can be None)
+        # channel_indexes can be None (=all channel in the stream) or a list or numpy.array
         # This must return a numpy array 2D (even with one channel).
         # This must return the orignal dtype. No conversion here.
         # This must as fast as possible.
-        # Everything that can be done in _parse_header() must not be here.
+        # To speed up this call all preparatory calculations should be implemented
+        # in _parse_header().
 
         # Here we are lucky:  our signals is always zeros!!
-        # it is not always the case
+        # it is not always the case :)
         # internally signals are int16
         # convertion to real units is done with self.header['signal_channels']
 
@@ -246,25 +287,35 @@ class ExampleRawIO(BaseRawIO):
         if i_stop is None:
             i_stop = 100000
 
-        assert i_start >= 0, "I don't like your jokes"
-        assert i_stop <= 100000, "I don't like your jokes"
+        if i_start < 0 or i_stop > 100000:
+            # some check
+            raise IndexError("I don't like your jokes")
 
         if channel_indexes is None:
-            nb_chan = 16
-        else:
+            nb_chan = 8
+        elif isinstance(channel_indexes, slice):
+            channel_indexes = np.arange(8, dtype='int')[channel_indexes]
             nb_chan = len(channel_indexes)
+        else:
+            channel_indexes = np.asarray(channel_indexes)
+            if any(channel_indexes < 0):
+                raise IndexError('bad boy')
+            if any(channel_indexes >= 8):
+                raise IndexError('big bad wolf')
+            nb_chan = len(channel_indexes)
+
         raw_signals = np.zeros((i_stop - i_start, nb_chan), dtype='int16')
         return raw_signals
 
-    def _spike_count(self, block_index, seg_index, unit_index):
-        # Must return the nb of spike for given (block_index, seg_index, unit_index)
+    def _spike_count(self, block_index, seg_index, spike_channel_index):
+        # Must return the nb of spikes for given (block_index, seg_index, spike_channel_index)
         # we are lucky:  our units have all the same nb of spikes!!
         # it is not always the case
         nb_spikes = 20
         return nb_spikes
 
-    def _get_spike_timestamps(self, block_index, seg_index, unit_index, t_start, t_stop):
-        # In our IO, timstamp are internally coded 'int64' and they
+    def _get_spike_timestamps(self, block_index, seg_index, spike_channel_index, t_start, t_stop):
+        # In our IO, timestamp are internally coded 'int64' and they
         # represent the index of the signals 10kHz
         # we are lucky: spikes have the same discharge in all segments!!
         # incredible neuron!! This is not always the case
@@ -291,7 +342,8 @@ class ExampleRawIO(BaseRawIO):
         spike_times /= 10000.  # because 10kHz
         return spike_times
 
-    def _get_spike_raw_waveforms(self, block_index, seg_index, unit_index, t_start, t_stop):
+    def _get_spike_raw_waveforms(self, block_index, seg_index, spike_channel_index,
+                                 t_start, t_stop):
         # this must return a 3D numpy array (nb_spike, nb_channel, nb_sample)
         # in the original dtype
         # this must be as fast as possible.
@@ -302,13 +354,14 @@ class ExampleRawIO(BaseRawIO):
 
         # In our IO waveforms come from all channels
         # they are int16
-        # convertion to real units is done with self.header['unit_channels']
+        # convertion to real units is done with self.header['spike_channels']
         # Here, we have a realistic case: all waveforms are only noise.
         # it is not always the case
         # we 20 spikes with a sweep of 50 (5ms)
 
         # trick to get how many spike in the slice
-        ts = self._get_spike_timestamps(block_index, seg_index, unit_index, t_start, t_stop)
+        ts = self._get_spike_timestamps(block_index, seg_index,
+                                        spike_channel_index, t_start, t_stop)
         nb_spike = ts.size
 
         np.random.seed(2205)  # a magic number (my birthday)
@@ -357,7 +410,7 @@ class ExampleRawIO(BaseRawIO):
 
         return timestamp, durations, labels
 
-    def _rescale_event_timestamp(self, event_timestamps, dtype):
+    def _rescale_event_timestamp(self, event_timestamps, dtype, event_channel_index):
         # must rescale to second a particular event_timestamps
         # with a fixed dtype so the user can choose the precisino he want.
 
@@ -365,7 +418,7 @@ class ExampleRawIO(BaseRawIO):
         event_times = event_timestamps.astype(dtype)
         return event_times
 
-    def _rescale_epoch_duration(self, raw_duration, dtype):
+    def _rescale_epoch_duration(self, raw_duration, dtype, event_channel_index):
         # really easy here because in our case it is already seconds
         durations = raw_duration.astype(dtype)
         return durations
