@@ -22,10 +22,9 @@ http://www.neuroexplorer.com/downloadspage/
 Author: Samuel Garcia, luc estebanez, mark hollenbeck
 
 """
-# from __future__ import unicode_literals is not compatible with numpy.dtype both py2 py3
 
-from .baserawio import (BaseRawIO, _signal_channel_dtype, _unit_channel_dtype,
-                        _event_channel_dtype)
+from .baserawio import (BaseRawIO, _signal_channel_dtype, _signal_stream_dtype,
+                _spike_channel_dtype, _event_channel_dtype)
 
 import numpy as np
 from collections import OrderedDict
@@ -57,14 +56,14 @@ class NeuroExplorerRawIO(BaseRawIO):
         self._sig_lengths = []
         self._sig_t_starts = []
         sig_channels = []
-        unit_channels = []
+        spike_channels = []
         event_channels = []
         for i in range(self.global_header['nvar']):
             entity_header = self._entity_headers[i]
             name = entity_header['name']
-            _id = i
+            _id = str(i)
             if entity_header['type'] == 0:  # Unit
-                unit_channels.append((name, _id, '', 0, 0, 0, 0))
+                spike_channels.append((name, _id, '', 0, 0, 0, 0))
 
             elif entity_header['type'] == 1:  # Event
                 event_channels.append((name, _id, 'event'))
@@ -78,7 +77,7 @@ class NeuroExplorerRawIO(BaseRawIO):
                 wf_offset = entity_header['MVOffset']
                 wf_left_sweep = 0
                 wf_sampling_rate = entity_header['WFrequency']
-                unit_channels.append((name, _id, wf_units, wf_gain, wf_offset,
+                spike_channels.append((name, _id, wf_units, wf_gain, wf_offset,
                                       wf_left_sweep, wf_sampling_rate))
 
             elif entity_header['type'] == 4:
@@ -91,9 +90,9 @@ class NeuroExplorerRawIO(BaseRawIO):
                 dtype = 'int16'
                 gain = entity_header['ADtoMV']
                 offset = entity_header['MVOffset']
-                group_id = 0
+                stream_id = str(_id)
                 sig_channels.append((name, _id, sampling_rate, dtype, units,
-                                     gain, offset, group_id))
+                                     gain, offset, stream_id))
                 self._sig_lengths.append(entity_header['NPointsWave'])
                 # sig t_start is the first timestamp if datablock
                 offset = entity_header['offset']
@@ -105,19 +104,23 @@ class NeuroExplorerRawIO(BaseRawIO):
                 event_channels.append((name, _id, 'event'))
 
         sig_channels = np.array(sig_channels, dtype=_signal_channel_dtype)
-        unit_channels = np.array(unit_channels, dtype=_unit_channel_dtype)
+        spike_channels = np.array(spike_channels, dtype=_spike_channel_dtype)
         event_channels = np.array(event_channels, dtype=_event_channel_dtype)
 
         # each signal channel have a dierent groups that force reading
         # them one by one
-        sig_channels['group_id'] = np.arange(sig_channels.size)
+        sig_channels['stream_id'] = np.arange(sig_channels.size).astype('U')
+        signal_streams = np.zeros(sig_channels.size, dtype=_signal_stream_dtype)
+        signal_streams['name'] = sig_channels['name']
+        signal_streams['id'] = sig_channels['stream_id']
 
         # fill into header dict
         self.header = {}
         self.header['nb_block'] = 1
         self.header['nb_segment'] = [1]
+        self.header['signal_streams'] = signal_streams
         self.header['signal_channels'] = sig_channels
-        self.header['unit_channels'] = unit_channels
+        self.header['spike_channels'] = spike_channels
         self.header['event_channels'] = event_channels
 
         # Annotations
@@ -136,17 +139,15 @@ class NeuroExplorerRawIO(BaseRawIO):
         t_stop = self.global_header['tend'] / self.global_header['freq']
         return t_stop
 
-    def _get_signal_size(self, block_index, seg_index, channel_indexes):
-        assert len(channel_indexes) == 1, 'only one channel by one channel'
-        return self._sig_lengths[channel_indexes[0]]
+    def _get_signal_size(self, block_index, seg_index, stream_index):
+        return self._sig_lengths[stream_index]
 
-    def _get_signal_t_start(self, block_index, seg_index, channel_indexes):
-        assert len(channel_indexes) == 1, 'only one channel by one channel'
-        return self._sig_t_starts[channel_indexes[0]]
+    def _get_signal_t_start(self, block_index, seg_index, stream_index):
+        return self._sig_t_starts[stream_index]
 
-    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop, channel_indexes):
-        assert len(channel_indexes) == 1, 'only one channel by one channel'
-        channel_index = channel_indexes[0]
+    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop,
+                                stream_index, channel_indexes):
+        channel_index = stream_index
         entity_index = int(self.header['signal_channels'][channel_index]['id'])
         entity_header = self._entity_headers[entity_index]
         n = entity_header['n']
@@ -161,13 +162,13 @@ class NeuroExplorerRawIO(BaseRawIO):
         return raw_signal
 
     def _spike_count(self, block_index, seg_index, unit_index):
-        entity_index = int(self.header['unit_channels'][unit_index]['id'])
+        entity_index = int(self.header['spike_channels'][unit_index]['id'])
         entity_header = self._entity_headers[entity_index]
         nb_spike = entity_header['n']
         return nb_spike
 
     def _get_spike_timestamps(self, block_index, seg_index, unit_index, t_start, t_stop):
-        entity_index = int(self.header['unit_channels'][unit_index]['id'])
+        entity_index = int(self.header['spike_channels'][unit_index]['id'])
         entity_header = self._entity_headers[entity_index]
         n = entity_header['n']
         offset = entity_header['offset']
@@ -188,7 +189,7 @@ class NeuroExplorerRawIO(BaseRawIO):
         return spike_times
 
     def _get_spike_raw_waveforms(self, block_index, seg_index, unit_index, t_start, t_stop):
-        entity_index = int(self.header['unit_channels'][unit_index]['id'])
+        entity_index = int(self.header['spike_channels'][unit_index]['id'])
         entity_header = self._entity_headers[entity_index]
         if entity_header['type'] == 0:
             return None
@@ -245,12 +246,12 @@ class NeuroExplorerRawIO(BaseRawIO):
 
         return timestamps, durations, labels
 
-    def _rescale_event_timestamp(self, event_timestamps, dtype):
+    def _rescale_event_timestamp(self, event_timestamps, dtype, event_channel_index):
         event_times = event_timestamps.astype(dtype)
         event_times /= self.global_header['freq']
         return event_times
 
-    def _rescale_epoch_duration(self, raw_duration, dtype):
+    def _rescale_epoch_duration(self, raw_duration, dtype, event_channel_index):
         durations = raw_duration.astype(dtype)
         durations /= self.global_header['freq']
         return durations
