@@ -4,14 +4,17 @@ RawIO Class for NIX files
 The RawIO assumes all segments and all blocks have the same structure.
 It supports all kinds of NEO objects.
 
-Author: Chek Yin Choi
+Author: Chek Yin Choi, Julia Sprenger
 """
 
-from .baserawio import (BaseRawIO, _signal_channel_dtype,
-                        _unit_channel_dtype, _event_channel_dtype)
-from ..io.nixio import NixIO
-from ..io.nixio import check_nix_version
+import os.path
+
 import numpy as np
+
+from .baserawio import (BaseRawIO, _signal_channel_dtype, _signal_stream_dtype,
+                        _spike_channel_dtype, _event_channel_dtype)
+from ..io.nixio import check_nix_version
+
 try:
     import nixio as nix
 
@@ -41,15 +44,16 @@ class NIXRawIO(BaseRawIO):
     def __init__(self, filename=''):
         check_nix_version()
         BaseRawIO.__init__(self)
-        self.filename = filename
+        self.filename = str(filename)
 
     def _source_name(self):
         return self.filename
 
     def _parse_header(self):
         self.file = nix.File.open(self.filename, nix.FileMode.ReadOnly)
-        sig_channels = []
-        size_list = []
+        signal_channels = []
+        anasig_ids = {0: []}  # ids of analogsignals by segment
+        stream_ids = []
         for bl in self.file.blocks:
             for seg in bl.groups:
                 for da_idx, da in enumerate(seg.data_arrays):
@@ -59,29 +63,32 @@ class NIXRawIO(BaseRawIO):
                         units = str(da.unit)
                         dtype = str(da.dtype)
                         sr = 1 / da.dimensions[0].sampling_interval
-                        da_leng = da.size
-                        if da_leng not in size_list:
-                            size_list.append(da_leng)
-                        group_id = 0
-                        for sid, li_leng in enumerate(size_list):
-                            if li_leng == da_leng:
-                                group_id = sid
-                                # very important! group_id use to store
-                                # channel groups!!!
-                                # use only for different signal length
+                        anasig_id = da.name.split('.')[-2]
+                        if anasig_id not in anasig_ids[0]:
+                            anasig_ids[0].append(anasig_id)
+                        stream_id = anasig_ids[0].index(anasig_id)
+                        if stream_id not in stream_ids:
+                            stream_ids.append(stream_id)
                         gain = 1
                         offset = 0.
-                        sig_channels.append((ch_name, chan_id, sr, dtype,
-                                            units, gain, offset, group_id))
+                        signal_channels.append((ch_name, chan_id, sr, dtype,
+                                            units, gain, offset, stream_id))
+                # only read structure of first segment and assume the same
+                # across segments
                 break
             break
-        sig_channels = np.array(sig_channels, dtype=_signal_channel_dtype)
+        signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
+        signal_streams = np.zeros(len(stream_ids), dtype=_signal_stream_dtype)
+        signal_streams['id'] = stream_ids
+        signal_streams['name'] = ''
 
-        unit_channels = []
+        spike_channels = []
         unit_name = ""
         unit_id = ""
         for bl in self.file.blocks:
-            for seg in bl.groups:
+            seg_groups = [g for g in bl.groups if g.type == "neo.segment"]
+
+            for seg in seg_groups:
                 for mt in seg.multi_tags:
                     if mt.type == "neo.spiketrain":
                         unit_name = mt.metadata['neo_name']
@@ -99,19 +106,20 @@ class NIXRawIO(BaseRawIO):
                                 wf_left_sweep = wf.metadata["left_sweep"]
                         wf_gain = 1
                         wf_offset = 0.
-                        unit_channels.append(
+                        spike_channels.append(
                             (unit_name, unit_id, wf_units, wf_gain,
                              wf_offset, wf_left_sweep, wf_sampling_rate)
                         )
                 break
             break
-        unit_channels = np.array(unit_channels, dtype=_unit_channel_dtype)
+        spike_channels = np.array(spike_channels, dtype=_spike_channel_dtype)
 
         event_channels = []
         event_count = 0
         epoch_count = 0
         for bl in self.file.blocks:
-            for seg in bl.groups:
+            seg_groups = [g for g in bl.groups if g.type == "neo.segment"]
+            for seg in seg_groups:
                 for mt in seg.multi_tags:
                     if mt.type == "neo.event":
                         ev_name = mt.metadata['neo_name']
@@ -131,9 +139,10 @@ class NIXRawIO(BaseRawIO):
 
         self.da_list = {'blocks': []}
         for block_index, blk in enumerate(self.file.blocks):
+            seg_groups = [g for g in blk.groups if g.type == "neo.segment"]
             d = {'segments': []}
             self.da_list['blocks'].append(d)
-            for seg_index, seg in enumerate(blk.groups):
+            for seg_index, seg in enumerate(seg_groups):
                 d = {'signals': []}
                 self.da_list['blocks'][block_index]['segments'].append(d)
                 size_list = []
@@ -152,9 +161,10 @@ class NIXRawIO(BaseRawIO):
 
         self.unit_list = {'blocks': []}
         for block_index, blk in enumerate(self.file.blocks):
+            seg_groups = [g for g in blk.groups if g.type == "neo.segment"]
             d = {'segments': []}
             self.unit_list['blocks'].append(d)
-            for seg_index, seg in enumerate(blk.groups):
+            for seg_index, seg in enumerate(seg_groups):
                 d = {'spiketrains': [],
                      'spiketrains_id': [],
                      'spiketrains_unit': []}
@@ -169,8 +179,7 @@ class NIXRawIO(BaseRawIO):
                         segment['spiketrains'].append(st.positions)
                         segment['spiketrains_id'].append(st.id)
                         wftypestr = "neo.waveforms"
-                        if (st.features
-                                and st.features[0].data.type == wftypestr):
+                        if (st.features and st.features[0].data.type == wftypestr):
                             waveforms = st.features[0].data
                             stdict = segment['spiketrains_unit'][st_idx]
                             if waveforms:
@@ -182,37 +191,31 @@ class NIXRawIO(BaseRawIO):
 
         self.header = {}
         self.header['nb_block'] = len(self.file.blocks)
-        self.header['nb_segment'] = [len(bl.groups) for bl in self.file.blocks]
-        self.header['signal_channels'] = sig_channels
-        self.header['unit_channels'] = unit_channels
+        self.header['nb_segment'] = [
+            len(seg_groups)
+            for bl in self.file.blocks
+        ]
+        self.header['signal_streams'] = signal_streams
+        self.header['signal_channels'] = signal_channels
+        self.header['spike_channels'] = spike_channels
         self.header['event_channels'] = event_channels
 
         self._generate_minimal_annotations()
         for blk_idx, blk in enumerate(self.file.blocks):
+            seg_groups = [g for g in blk.groups if g.type == "neo.segment"]
             bl_ann = self.raw_annotations['blocks'][blk_idx]
             props = blk.metadata.inherited_properties()
             bl_ann.update(self._filter_properties(props, "block"))
-            for grp_idx, grp in enumerate(blk.groups):
+            for grp_idx, group in enumerate(seg_groups):
                 seg_ann = bl_ann['segments'][grp_idx]
-                props = grp.metadata.inherited_properties()
+                props = group.metadata.inherited_properties()
                 seg_ann.update(self._filter_properties(props, "segment"))
-                sig_idx = 0
-                groupdas = NixIO._group_signals(grp.data_arrays)
-                for nix_name, signals in groupdas.items():
-                    da = signals[0]
-                    if da.type == 'neo.analogsignal' and seg_ann['signals']:
-                        # collect and group DataArrays
-                        sig_ann = seg_ann['signals'][sig_idx]
-                        sig_chan_ann = self.raw_annotations['signal_channels'][sig_idx]
-                        props = da.metadata.inherited_properties()
-                        sig_ann.update(self._filter_properties(props, 'analogsignal'))
-                        sig_chan_ann.update(self._filter_properties(props, 'analogsignal'))
-                        sig_idx += 1
+
                 sp_idx = 0
                 ev_idx = 0
-                for mt in grp.multi_tags:
-                    if mt.type == 'neo.spiketrain' and seg_ann['units']:
-                        st_ann = seg_ann['units'][sp_idx]
+                for mt in group.multi_tags:
+                    if mt.type == 'neo.spiketrain' and seg_ann['spikes']:
+                        st_ann = seg_ann['spikes'][sp_idx]
                         props = mt.metadata.inherited_properties()
                         st_ann.update(self._filter_properties(props, 'spiketrain'))
                         sp_idx += 1
@@ -225,11 +228,37 @@ class NIXRawIO(BaseRawIO):
                             event_ann.update(self._filter_properties(props, 'event'))
                             ev_idx += 1
 
-                # populate ChannelIndex annotations
-                for srcidx, source in enumerate(blk.sources):
-                    chx_ann = self.raw_annotations["signal_channels"][srcidx]
-                    props = source.metadata.inherited_properties()
-                    chx_ann.update(self._filter_properties(props, "channelindex"))
+                # adding array annotations to analogsignals
+                annotated_anasigs = []
+                sig_ann = seg_ann['signals']
+                # this implementation relies on analogsignals always being
+                # stored in the same stream order across segments
+                stream_id = 0
+                for da_idx, da in enumerate(group.data_arrays):
+                    if da.type != "neo.analogsignal":
+                        continue
+                    anasig_id = da.name.split('.')[-2]
+                    # skip already annotated signals as each channel already
+                    # contains the complete set of annotations and
+                    # array_annotations
+                    if anasig_id in annotated_anasigs:
+                        continue
+                    annotated_anasigs.append(anasig_id)
+
+                    # collect annotation properties
+                    props = [p for p in da.metadata.props
+                             if p.type != 'ARRAYANNOTATION']
+                    props_dict = self._filter_properties(props, "analogsignal")
+                    sig_ann[stream_id].update(props_dict)
+
+                    # collect array annotation properties
+                    props = [p for p in da.metadata.props
+                             if p.type == 'ARRAYANNOTATION']
+                    props_dict = self._filter_properties(props, "analogsignal")
+                    sig_ann[stream_id]['__array_annotations__'].update(
+                        props_dict)
+
+                    stream_id += 1
 
     def _segment_t_start(self, block_index, seg_index):
         t_start = 0
@@ -245,18 +274,20 @@ class NIXRawIO(BaseRawIO):
                 t_stop = mt.metadata['t_stop']
         return t_stop
 
-    def _get_signal_size(self, block_index, seg_index, channel_indexes):
-        if channel_indexes is None:
-            channel_indexes = list(range(self.header['signal_channels'].size))
+    def _get_signal_size(self, block_index, seg_index, stream_index):
+        stream_id = self.header['signal_streams'][stream_index]['id']
+        keep = self.header['signal_channels']['stream_id'] == stream_id
+        channel_indexes, = np.nonzero(keep)
         ch_idx = channel_indexes[0]
         block = self.da_list['blocks'][block_index]
         segment = block['segments'][seg_index]
         size = segment['data_size'][ch_idx]
         return size  # size is per signal, not the sum of all channel_indexes
 
-    def _get_signal_t_start(self, block_index, seg_index, channel_indexes):
-        if channel_indexes is None:
-            channel_indexes = list(range(self.header['signal_channels'].size))
+    def _get_signal_t_start(self, block_index, seg_index, stream_index):
+        stream_id = self.header['signal_streams'][stream_index]['id']
+        keep = self.header['signal_channels']['stream_id'] == stream_id
+        channel_indexes, = np.nonzero(keep)
         ch_idx = channel_indexes[0]
         block = self.file.blocks[block_index]
         das = [da for da in block.groups[seg_index].data_arrays]
@@ -264,22 +295,22 @@ class NIXRawIO(BaseRawIO):
         sig_t_start = float(da.metadata['t_start'])
         return sig_t_start  # assume same group_id always same t_start
 
-    def _get_analogsignal_chunk(self, block_index, seg_index,
-                                i_start, i_stop, channel_indexes):
-        if channel_indexes is None:
-            channel_indexes = list(range(self.header['signal_channels'].size))
+    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop,
+                                stream_index, channel_indexes):
+        stream_id = self.header['signal_streams'][stream_index]['id']
+        keep = self.header['signal_channels']['stream_id'] == stream_id
+        global_channel_indexes, = np.nonzero(keep)
+        if channel_indexes is not None:
+            global_channel_indexes = global_channel_indexes[channel_indexes]
+
         if i_start is None:
             i_start = 0
         if i_stop is None:
-            block = self.da_list['blocks'][block_index]
-            segment = block['segments'][seg_index]
-            for c in channel_indexes:
-                i_stop = segment['data_size'][c]
-                break
+            i_stop = self.get_signal_size(block_index, seg_index, stream_index)
 
         raw_signals_list = []
         da_list = self.da_list['blocks'][block_index]['segments'][seg_index]
-        for idx in channel_indexes:
+        for idx in global_channel_indexes:
             da = da_list['data'][idx]
             raw_signals_list.append(da[i_start:i_stop])
 
@@ -289,7 +320,7 @@ class NIXRawIO(BaseRawIO):
 
     def _spike_count(self, block_index, seg_index, unit_index):
         count = 0
-        head_id = self.header['unit_channels'][unit_index][1]
+        head_id = self.header['spike_channels'][unit_index][1]
         for mt in self.file.blocks[block_index].groups[seg_index].multi_tags:
             for src in mt.sources:
                 if mt.type == 'neo.spiketrain' and [src.type == "neo.unit"]:
@@ -358,8 +389,7 @@ class NIXRawIO(BaseRawIO):
             if mt.type == "neo.event" or mt.type == "neo.epoch":
                 labels.append(mt.positions.dimensions[0].labels)
                 po = mt.positions
-                if (po.type == "neo.event.times"
-                        or po.type == "neo.epoch.times"):
+                if (po.type == "neo.event.times" or po.type == "neo.epoch.times"):
                     timestamp.append(po)
                 channel = self.header['event_channels'][event_channel_index]
                 if channel['type'] == b'epoch' and mt.extents:
@@ -379,7 +409,7 @@ class NIXRawIO(BaseRawIO):
             timestamp, labels = timestamp[keep], labels[keep]
         return timestamp, durations, labels  # only the first fits in rescale
 
-    def _rescale_event_timestamp(self, event_timestamps, dtype='float64'):
+    def _rescale_event_timestamp(self, event_timestamps, dtype, event_channel_index):
         ev_unit = ''
         for mt in self.file.blocks[0].groups[0].multi_tags:
             if mt.type == "neo.event":
@@ -391,7 +421,7 @@ class NIXRawIO(BaseRawIO):
         # supposing unit is second, other possibilities maybe mS microS...
         return event_times  # return in seconds
 
-    def _rescale_epoch_duration(self, raw_duration, dtype='float64'):
+    def _rescale_epoch_duration(self, raw_duration, dtype, event_channel_index):
         ep_unit = ''
         for mt in self.file.blocks[0].groups[0].multi_tags:
             if mt.type == "neo.epoch":
