@@ -17,8 +17,8 @@ Important release note:
 Author: Samuel Garcia
 """
 
-from .baserawio import (BaseRawIO, _signal_channel_dtype, _unit_channel_dtype,
-                        _event_channel_dtype)
+from .baserawio import (BaseRawIO, _signal_channel_dtype, _signal_stream_dtype,
+                _spike_channel_dtype, _event_channel_dtype)
 
 import numpy as np
 
@@ -53,32 +53,39 @@ class RawBinarySignalRawIO(BaseRawIO):
             # The the neo.io.RawBinarySignalIO is used for write_segment
             self._raw_signals = None
 
-        sig_channels = []
+        signal_channels = []
         if self._raw_signals is not None:
             for c in range(self.nb_channel):
-                name = 'ch{}'.format(c)
-                chan_id = c
+                name = f'ch{c}'
+                chan_id = f'{c}'
                 units = ''
-                group_id = 0
-                sig_channels.append((name, chan_id, self.sampling_rate, self.dtype,
-                                     units, self.signal_gain, self.signal_offset, group_id))
+                stream_id = '0'
+                signal_channels.append((name, chan_id, self.sampling_rate, self.dtype,
+                                     units, self.signal_gain, self.signal_offset, stream_id))
 
-        sig_channels = np.array(sig_channels, dtype=_signal_channel_dtype)
+        signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
+
+        # one unique stream
+        if signal_channels.size > 0:
+            signal_streams = np.array([('Signals', '0')], dtype=_signal_stream_dtype)
+        else:
+            signal_streams = np.array([], dtype=_signal_stream_dtype)
 
         # No events
         event_channels = []
         event_channels = np.array(event_channels, dtype=_event_channel_dtype)
 
         # No spikes
-        unit_channels = []
-        unit_channels = np.array(unit_channels, dtype=_unit_channel_dtype)
+        spike_channels = []
+        spike_channels = np.array(spike_channels, dtype=_spike_channel_dtype)
 
         # fille into header dict
         self.header = {}
         self.header['nb_block'] = 1
         self.header['nb_segment'] = [1]
-        self.header['signal_channels'] = sig_channels
-        self.header['unit_channels'] = unit_channels
+        self.header['signal_streams'] = signal_streams
+        self.header['signal_channels'] = signal_channels
+        self.header['spike_channels'] = spike_channels
         self.header['event_channels'] = event_channels
 
         # insert some annotation at some place
@@ -91,15 +98,17 @@ class RawBinarySignalRawIO(BaseRawIO):
         t_stop = self._raw_signals.shape[0] / self.sampling_rate
         return t_stop
 
-    def _get_signal_size(self, block_index, seg_index, channel_indexes):
+    def _get_signal_size(self, block_index, seg_index, stream_index):
+        assert stream_index == 0
         return self._raw_signals.shape[0]
 
-    def _get_signal_t_start(self, block_index, seg_index, channel_indexes):
+    def _get_signal_t_start(self, block_index, seg_index, stream_index):
+        assert stream_index == 0
         return 0.
 
-    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop, channel_indexes):
+    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop,
+                                stream_index, channel_indexes):
         if channel_indexes is None:
             channel_indexes = slice(None)
         raw_signals = self._raw_signals[slice(i_start, i_stop), channel_indexes]
-
         return raw_signals
