@@ -13,8 +13,8 @@ import quantities as pq
 from neo.io.blackrockio import BlackrockIO
 
 from neo.test.iotest.common_io_test import BaseTestIO
-from neo.test.iotest.tools import get_test_file_full_path
 from neo.test.tools import assert_neo_object_is_compliant
+from neo.test.rawiotest.test_blackrockrawio import TestBlackrockRawIO
 
 # check scipy
 try:
@@ -37,32 +37,16 @@ else:
 
 class CommonTests(BaseTestIO, unittest.TestCase):
     ioclass = BlackrockIO
-
-    files_to_test = ['FileSpec2.3001',
-        'blackrock_2_1/l101210-001']
-
-    files_to_download = [
-        'FileSpec2.3001.nev',
-        'FileSpec2.3001.ns5',
-        'FileSpec2.3001.ccf',
-        'FileSpec2.3001.mat',
-        'blackrock_2_1/l101210-001.mat',
-        'blackrock_2_1/l101210-001_nev-02_ns5.mat',
-        'blackrock_2_1/l101210-001.ns2',
-        'blackrock_2_1/l101210-001.ns5',
-        'blackrock_2_1/l101210-001.nev',
-        'blackrock_2_1/l101210-001-02.nev',
-        'segment/PauseCorrect/pause_correct.nev',
-        'segment/PauseCorrect/pause_correct.ns2',
-        'segment/PauseSpikesOutside/pause_spikes_outside_seg.nev',
-        'segment/ResetCorrect/reset.nev',
-        'segment/ResetCorrect/reset.ns2',
-        'segment/ResetFail/reset_fail.nev']
-
-    ioclass = BlackrockIO
+    entities_to_download = [
+        'blackrock'
+    ]
+    entities_to_test = [
+        'blackrock/FileSpec2.3001',
+        'blackrock/blackrock_2_1/l101210-001'
+    ]
 
     def test_load_waveforms(self):
-        filename = self.get_filename_path('FileSpec2.3001')
+        filename = self.get_local_path('blackrock/FileSpec2.3001')
         reader = BlackrockIO(filename=filename, verbose=False)
 
         bl = reader.read_block(load_waveforms=True)
@@ -73,7 +57,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         Test various inputs to BlackrockIO.read_block with version 2.3 file
         to check for parsing errors.
         """
-        filename = self.get_filename_path('FileSpec2.3001')
+        filename = self.get_local_path('blackrock/FileSpec2.3001')
         reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load=5)
 
         # Assert IOError is raised when no Blackrock files are available
@@ -124,7 +108,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         Test various inputs to BlackrockIO.read_block with version 2.3 file
         to check for parsing errors.
         """
-        filename = self.get_filename_path('blackrock_2_1/l101210-001')
+        filename = self.get_local_path('blackrock/blackrock_2_1/l101210-001')
         reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load=5)
 
         # Assert IOError is raised when no Blackrock files are available
@@ -176,7 +160,7 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         """
         Test if multiple nsx signals can be loaded at the same time.
         """
-        filename = self.get_filename_path('blackrock_2_1/l101210-001')
+        filename = self.get_local_path('blackrock/blackrock_2_1/l101210-001')
         reader = BlackrockIO(filename=filename, verbose=False, nsx_to_load='all')
 
         # number of different sampling rates corresponds to number of nsx signals, because
@@ -231,20 +215,14 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         The function tests LFPs, spike times, and digital events.
         """
 
-        dirname = get_test_file_full_path(ioclass=BlackrockIO,
-                                          filename='blackrock_2_1/l101210-001',
-                                          directory=self.local_test_dir, clean=False)
+        dirname = self.get_local_path('blackrock/blackrock_2_1/l101210-001')
         # First run with parameters for ns5, then run with correct parameters for ns2
-        parameters = [('blackrock_2_1/l101210-001_nev-02_ns5.mat',
+        parameters = [('blackrock/blackrock_2_1/l101210-001_nev-02_ns5.mat',
                        {'nsx_to_load': 5, 'nev_override': '-'.join([dirname, '02'])}),
-                      ('blackrock_2_1/l101210-001.mat', {'nsx_to_load': 2})]
+                      ('blackrock/blackrock_2_1/l101210-001.mat', {'nsx_to_load': 2})]
         for index, param in enumerate(parameters):
             # Load data from matlab generated files
-            ml = scipy.io.loadmat(
-                get_test_file_full_path(
-                    ioclass=BlackrockIO,
-                    filename=param[0],
-                    directory=self.local_test_dir, clean=False))
+            ml = scipy.io.loadmat(self.get_local_path(param[0]))
             lfp_ml = ml['lfp']  # (channel x time) LFP matrix
             ts_ml = ml['ts']  # spike time stamps
             elec_ml = ml['el']  # spike electrodes
@@ -260,35 +238,6 @@ class CommonTests(BaseTestIO, unittest.TestCase):
             block = session.read_block(load_waveforms=True, signal_group_mode='split-all')
             # Check if analog data are equal
             self.assertGreater(len(block.groups), 0)
-            for i, chidx_grp in enumerate(block.channel_indexes):
-                # Break for ChannelIndexes for Units that don't contain any Analogsignals
-                if len(chidx_grp.analogsignals) == 0 and len(chidx_grp.spiketrains) >= 1:
-                    break
-                # Should only have one AnalogSignal per ChannelIndex-representing Group
-                self.assertEqual(len(chidx_grp.analogsignals), 1)
-
-                # Find out channel_id in order to compare correctly
-                idx = chidx_grp.analogsignals[0].annotations['channel_id']
-                # Get data of AnalogSignal without pq.units
-                anasig = np.squeeze(chidx_grp.analogsignals[0].base[:].magnitude)
-                # Test for equality of first nonzero values of AnalogSignal
-                #                                   and matlab file contents
-                # If not equal test if hardcoded gain is responsible for this
-                # See BlackrockRawIO ll. 1420 commit 77a645655605ae39eca2de3ee511f3b522f11bd7
-                j = 0
-                while anasig[j] == 0:
-                    j += 1
-                if lfp_ml[i, j] != np.squeeze(chidx_grp.analogsignals[0].base[j].magnitude):
-                    anasig = anasig / 152.592547
-                    anasig = np.round(anasig).astype(int)
-
-                # Special case because id 142 is not included in ns2 file
-                if idx == 143:
-                    idx -= 1
-                if idx > 128:
-                    idx = idx - 136
-
-                assert_equal(anasig, lfp_ml[idx - 1, :])
 
             # Check if spikes are equal
             self.assertEqual(len(block.segments), 1)
@@ -334,9 +283,9 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         """
 
         # Path to nev that will fail
-        filename_nev_fail = self.get_filename_path('segment/ResetFail/reset_fail')
+        filename_nev_fail = self.get_local_path('blackrock/segment/ResetFail/reset_fail')
         # Path to nsX and nev that will NOT fail
-        filename = self.get_filename_path('segment/ResetCorrect/reset')
+        filename = self.get_local_path('blackrock/segment/ResetCorrect/reset')
 
         # Warning filter needs to be set to always before first occurrence of this warning
         warnings.simplefilter("always", UserWarning)
@@ -391,10 +340,10 @@ class CommonTests(BaseTestIO, unittest.TestCase):
         """
 
         # Path to nev that has spikes that don't fit nsX segment
-        filename_nev_outside_seg = self.get_filename_path(
-            'segment/PauseSpikesOutside/pause_spikes_outside_seg')
+        filename_nev_outside_seg = self.get_local_path(
+            'blackrock/segment/PauseSpikesOutside/pause_spikes_outside_seg')
         # Path to nsX and nev that are correct
-        filename = self.get_filename_path('segment/PauseCorrect/pause_correct')
+        filename = self.get_local_path('blackrock/segment/PauseCorrect/pause_correct')
 
         # This issues a warning, because there are spikes a long time after the last segment
         # And another one because there are spikes between segments
