@@ -10,11 +10,14 @@ from neo.test.iotest.common_io_test import BaseTestIO
 
 class TestWinedrIO(BaseTestIO, unittest.TestCase, ):
     ioclass = WinEdrIO
-    files_to_test = ['File_WinEDR_1.EDR',
-                     'File_WinEDR_2.EDR',
-                     'File_WinEDR_3.EDR',
-                     ]
-    files_to_download = files_to_test
+    entities_to_download = [
+        'winedr'
+    ]
+    entities_to_test = [
+        'winedr/File_WinEDR_1.EDR',
+        'winedr/File_WinEDR_2.EDR',
+        'winedr/File_WinEDR_3.EDR',
+    ]
 
 
 if __name__ == "__main__":
