@@ -7,11 +7,13 @@ from neo.test.rawiotest.common_rawio_test import BaseTestRawIO
 
 class TestNeuroExplorerRawIO(BaseTestRawIO, unittest.TestCase, ):
     rawioclass = NeuroExplorerRawIO
+    entities_to_download = [
+        'neuroexplorer'
+    ]
     files_to_download = [
-        'File_neuroexplorer_1.nex',
-        'File_neuroexplorer_2.nex',
+        'neuroexplorer/File_neuroexplorer_1.nex',
+        'neuroexplorer/File_neuroexplorer_2.nex',
     ]
-    entities_to_test = files_to_download
 
 
 if __name__ == "__main__":
