@@ -6,12 +6,14 @@ from neo.test.rawiotest.common_rawio_test import BaseTestRawIO
 
 class TestWinEdrRawIO(BaseTestRawIO, unittest.TestCase, ):
     rawioclass = WinEdrRawIO
-    files_to_download = [
-        'File_WinEDR_1.EDR',
-        'File_WinEDR_2.EDR',
-        'File_WinEDR_3.EDR',
+    entities_to_download = [
+        'winedr'
+    ]
+    entities_to_test = [
+        'winedr/File_WinEDR_1.EDR',
+        'winedr/File_WinEDR_2.EDR',
+        'winedr/File_WinEDR_3.EDR',
     ]
-    entities_to_test = files_to_download
 
 
 if __name__ == "__main__":
